from zope.interface import Interface
# -*- Additional Imports Here -*-


class IPressKit(Interface):
    """Folder that holds press documents downloadable as a zip bundle."""

    # -*- schema definition goes here -*-
